Learn R Programming

MIDASim (version 2.0)

throat.otu.tab: throat microbiome dataset

Description

A microbiome dataset of 60 subjects with 856 OTUs. The data were collected from right and left nasopharynx and oropharynx region.

Usage

data(throat.otu.tab)

Arguments

Format

An object of class data.frame with 60 rows and 856 columns.

References

Charlson, E. S., Chen, J., Custers-Allen, R., Bittinger, K., Li, H., Sinha, R., Hwang, J., Bushman, F. D., & Collman, R. G. (2010). Disordered microbial communities in the upper respiratory tract of cigarette smokers. PloS one, 5(12), e15216. https://doi.org/10.1371/journal.pone.0015216

Examples

Run this code
data(throat.otu.tab)
# \donttest{
MIDASim.setup(otu.tab = throat.otu.tab, mode = "nonparametric")# }

Run the code above in your browser using DataLab